==> vss-ui-4.141.4.tgz: package/Components/VssPersona/VssPersona.js <==
import * as tslib_1 from "tslib";
import "../../FabricInit";
import * as React from "react";
import { BaseComponent, css } from "office-ui-fabric-react/lib/Utilities";
import "./VssPersona.css";
/**
 * Renders a user's profile/identity/avatar image.
 */
var VssPersona = /** @class */ (function (_super) {
    tslib_1.__extends(VssPersona, _super);
    function VssPersona(props) {
        var _this = _super.call(this, props) || this;
        _this._setTargetElement = function (element) {
            _this.targetElement = element;
        };
        _this._handleKeyDown = function (e) {
            if (e.keyCode === 13 /* enter */ || e.keyCode === 32 /* space */) {
                _this._showPersonaCard();
            }
        };
        _this._showPersonaCard = function () {
            if (!_this.props.suppressPersonaCard) {
                _this.setState({ showPersonaCard: true });
            }
        };
        _this._hidePersonaCard = function () {
            _this.setState({ showPersonaCard: false });
        };
        _this.state = {
            showPersonaCard: false,
            imageUrl: _this._getImageUrl(props),
        };
        return _this;
    }
    VssPersona.prototype.componentWillReceiveProps = function (nextProps) {
        this.setState({
            showPersonaCard: false,
            imageUrl: this._getImageUrl(nextProps),
        });
    };
    VssPersona.prototype.shouldComponentUpdate = function (nextProps, nextState) {
        if (!this.props.identityDetailsProvider && !nextProps.identityDetailsProvider) {
            return false;
        }
        else if (!this.props.identityDetailsProvider || !nextProps.identityDetailsProvider) {
            return true;
        }
        return (this.props.size !== nextProps.size)
            || (this.props.cssClass !== nextProps.cssClass)
            || (this.props.identityDetailsProvider !== nextProps.identityDetailsProvider)
            || (this.state.showPersonaCard !== nextState.showPersonaCard);
    };
    VssPersona.prototype.render = function () {
        var _a = this.props, identityDetailsProvider = _a.identityDetailsProvider, _b = _a.size, size = _b === void 0 ? "medium" : _b, _c = _a.imgAltText, imgAltText = _c === void 0 ? "" : _c;
        var className = css("vss-Persona", this.props.cssClass);
        var imgStyle;
        var sizePx;
        if (typeof size === "number") {
            imgStyle = {
                width: size,
                height: size,
            };
            sizePx = size;
        }
        else {
            className = css(className, size);
            sizePx = this._getSize(size);
        }
        // Set the focus and aria-expand attributes based on props passed
        var additionalAttributes = {};
        if (this.props.dataIsFocusable) {
            additionalAttributes["data-is-focusable"] = true;
        }
        if (this.props.isTabStop) {
            additionalAttributes["tabIndex"] = 0;
        }
        // Setting the aria-expanded property if suppressPersonaCard is false
        if (!this.props.suppressPersonaCard) {
            additionalAttributes["aria-expanded"] = this.state.showPersonaCard;
        }
        // Getting the reference to the div around the image because the Callout within PersonaCard has positioning problems in some cases when passing in img element as the target
        return React.createElement("div", tslib_1.__assign({ className: className, ref: this._setTargetElement, "aria-label": identityDetailsProvider.getDisplayName() }, additionalAttributes, { onKeyDown: this._handleKeyDown, onClick: this._showPersonaCard }),
            React.createElement("img", { style: imgStyle, src: this.state.imageUrl, alt: imgAltText, onError: this.props.onImageError }),
            this.state.showPersonaCard
                && !this.props.suppressPersonaCard
                && identityDetailsProvider.onRenderPersonaCard
                && identityDetailsProvider.onRenderPersonaCard(this.targetElement, this._hidePersonaCard));
    };
    /**
     * Resolve the URL for the profile image.
     * @param props
     */
    VssPersona.prototype._getImageUrl = function (props) {
        var identityDetailsProvider = props.identityDetailsProvider, _a = props.size, size = _a === void 0 ? "medium" : _a;
        var sizePx = typeof size === "number" ? size : this._getSize(size);
        return identityDetailsProvider.getIdentityImageUrl(sizePx);
    };
    /**
     * Get the size in pixels for the given css class.
     * @param size
     */
    VssPersona.prototype._getSize = function (size) {
        switch (size) {
            case "extra-extra-small": return 16;
            case "extra-small": return 18;
            case "small": return 24;
            case "small-plus": return 28;
            case "medium": return 32;
            case "medium-plus": return 40;
            default:
            case "large": return 48;
            case "extra-large": return 72;
        }
    };
    return VssPersona;
}(BaseComponent));
export { VssPersona };

==> vss-ui-4.142.1.tgz: package/Components/VssPersona/VssPersona.js <==
import * as tslib_1 from "tslib";
import "../../FabricInit";
import * as React from "react";
import { BaseComponent, css } from "office-ui-fabric-react/lib/Utilities";
import "./VssPersona.css";
/**
 * Renders a user's profile/identity/avatar image.
 */
var VssPersona = /** @class */ (function (_super) {
    tslib_1.__extends(VssPersona, _super);
    function VssPersona(props) {
        var _this = _super.call(this, props) || this;
        _this._setTargetElement = function (element) {
            _this.targetElement = element;
        };
        _this._handleKeyDown = function (e) {
            if (e.keyCode === 13 /* enter */ || e.keyCode === 32 /* space */) {
                _this._showPersonaCard();
            }
        };
        _this._showPersonaCard = function () {
            if (!_this.props.suppressPersonaCard) {
                _this.setState({ showPersonaCard: true });
            }
        };
        _this._hidePersonaCard = function () {
            _this.setState({ showPersonaCard: false });
        };
        _this.state = {
            showPersonaCard: false,
            imageUrl: _this._getImageUrl(props),
        };
        return _this;
    }
    VssPersona.prototype.componentWillReceiveProps = function (nextProps) {
        this.setState({
            showPersonaCard: false,
            imageUrl: this._getImageUrl(nextProps),
        });
    };
    VssPersona.prototype.shouldComponentUpdate = function (nextProps, nextState) {
        if (!this.props.identityDetailsProvider && !nextProps.identityDetailsProvider) {
            return false;
        }
        else if (!this.props.identityDetailsProvider || !nextProps.identityDetailsProvider) {
            return true;
        }
        return (this.props.size !== nextProps.size)
            || (this.props.cssClass !== nextProps.cssClass)
            || (this.props.identityDetailsProvider !== nextProps.identityDetailsProvider)
            || (this.state.showPersonaCard !== nextState.showPersonaCard);
    };
    VssPersona.prototype.render = function () {
        var _a = this.props, identityDetailsProvider = _a.identityDetailsProvider, _b = _a.size, size = _b === void 0 ? "medium" : _b, _c = _a.imgAltText, imgAltText = _c === void 0 ? "" : _c;
        var className = css("vss-Persona", this.props.cssClass);
        var imgStyle;
        var sizePx;
        if (typeof size === "number") {
            imgStyle = {
                width: size,
                height: size,
            };
            sizePx = size;
        }
        else {
            className = css(className, size);
            sizePx = this._getSize(size);
        }
        // Set the focus and aria-expand attributes based on props passed
        var additionalAttributes = {};
        if (this.props.dataIsFocusable) {
            additionalAttributes["data-is-focusable"] = true;
        }
        if (this.props.isTabStop) {
            additionalAttributes["tabIndex"] = 0;
        }
        // Setting the aria related properties and user action delegates only if suppressPersonaCard is false
        if (!this.props.suppressPersonaCard) {
            additionalAttributes["aria-expanded"] = this.state.showPersonaCard;
            additionalAttributes["onKeyDown"] = this._handleKeyDown;
            additionalAttributes["onClick"] = this._showPersonaCard;
        }
        var displayName = identityDetailsProvider.getDisplayName();
        if (displayName) {
            additionalAttributes["aria-label"] = displayName;
        }
        // Getting the reference to the div around the image because the Callout within PersonaCard has positioning problems in some cases when passing in img element as the target
        return React.createElement("div", tslib_1.__assign({ className: className, ref: this._setTargetElement }, additionalAttributes),
            React.createElement("img", { style: imgStyle, src: this.state.imageUrl, alt: imgAltText, onError: this.props.onImageError }),
            !this.props.suppressPersonaCard
                && this.state.showPersonaCard
                && identityDetailsProvider.onRenderPersonaCard
                && identityDetailsProvider.onRenderPersonaCard(this.targetElement, this._hidePersonaCard));
    };
    /**
     * Resolve the URL for the profile image.
     * @param props
     */
    VssPersona.prototype._getImageUrl = function (props) {
        var identityDetailsProvider = props.identityDetailsProvider, _a = props.size, size = _a === void 0 ? "medium" : _a;
        var sizePx = typeof size === "number" ? size : this._getSize(size);
        return identityDetailsProvider.getIdentityImageUrl(sizePx);
    };
    /**
     * Get the size in pixels for the given css class.
     * @param size
     */
    VssPersona.prototype._getSize = function (size) {
        switch (size) {
            case "extra-extra-small": return 16;
            case "extra-small": return 18;
            case "extra-small-plus": return 20;
            case "small": return 24;
            case "small-plus": return 28;
            case "medium": return 32;
            case "medium-plus": return 40;
            default:
            case "large": return 48;
            case "extra-large": return 72;
        }
    };
    return VssPersona;
}(BaseComponent));
export { VssPersona };
